@@ -38,7 +38,7 @@ import sys
 import os
 import re
 
-VERSION = "0.9.1"
+VERSION = "0.10.0"
 
 regexes = {
     "version_specifier": re.compile(r"([^=><]+)(.*)"),
@@ -54,8 +54,28 @@ def do_format(s, **kwargs):
         return str(s).format(**kwargs)
 
 
+class ScriptNotFound(Exception):
+    def __init__(self, location, name):
+        super().__init__()
+        self.name = name
+        self.location = location
+
+    def __str__(self):
+        available = ", ".join(
+            n.name for n in self.location.parent.iterdir() if "." not in n.name and n.exists()
+        )
+        return "\n".join(
+            [
+                "\nCouldn't find the executable!",
+                f"Wanted {self.name}",
+                f"Available is {available}",
+            ]
+        )
+
+
 class FailedToGetOutput(Exception):
     def __init__(self, error, stderr):
+        super().__init__()
         self.error = error
         self.stderr = stderr
 
@@ -65,6 +85,7 @@ class FailedToGetOutput(Exception):
 
 class VersionNotSpecified(Exception):
     def __init__(self, name):
+        super().__init__()
         self.name = name
 
     def __str__(self):
@@ -73,6 +94,7 @@ class VersionNotSpecified(Exception):
 
 class InvalidVersion(Exception):
     def __init__(self, want):
+        super().__init__()
         self.want = want
 
     def __str__(self):
@@ -407,7 +429,7 @@ class Starter(object):
 
         Represents the minimum version of python needed for the virtualenv.
 
-        This will always default to 3.6.
+        This will always default to 3.7.
 
     max_python_version
         An int, float, str, tuple or object with "version" of a tuple.
@@ -455,7 +477,7 @@ class Starter(object):
             self.deps = []
 
         if self.min_python_version is None:
-            self.min_python_version = 3.6
+            self.min_python_version = 3.7
 
         handler = PythonHandler(self.min_python_version, self.max_python_version)
         self.min_python = handler.min_python
@@ -495,15 +517,7 @@ class Starter(object):
         if default is not None:
             return default
 
-        raise Exception(
-            "\n".join(
-                [
-                    "\nCouldn't find the executable!",
-                    f"Wanted {name}",
-                    f"Available is {location.iterdir()}",
-                ]
-            )
-        )
+        raise ScriptNotFound(location, name)
 
     @memoized_property
     def venv_python(self):
@@ -513,7 +527,12 @@ class Starter(object):
         python_exe = None
         if self.venv_location.exists():
             finder = PythonHandler(self.min_python, self.max_python)
-            _, version_info = finder.version_for(self.venv_python)
+
+            try:
+                _, version_info = finder.version_for(self.venv_python)
+            except ScriptNotFound:
+                version_info = None
+
             if not finder.suitable(version_info):
                 # Make sure we can find a suitable python before we remove existing venv
                 try:
